@@ -49,14 +49,12 @@ class Puppet::Resource::Catalog::Compiler < Puppet::Indirector::Code
     node = node_from_request(facts, request)
     node.trusted_data = Puppet.lookup(:trusted_information) { Puppet::Context::TrustedInformation.local(node) }.to_h
 
-    node.environment.use_text_domain if node.environment
-
-    if catalog = compile(node, request.options)
-      return catalog
+    if node.environment
+      node.environment.with_text_domain do
+        compile(node, request.options)
+      end
     else
-      # This shouldn't actually happen; we should either return
-      # a config or raise an exception.
-      return nil
+      compile(node, request.options)
     end
   end
 
@@ -178,7 +176,6 @@ class Puppet::Resource::Catalog::Compiler < Puppet::Indirector::Code
     # TODO: get property/parameter defaults if entries are nil in the resource
     # For now they're hard-coded to match the File type.
 
-    file_metadata = {}
     list_of_resources.each do |resource|
       sources = [resource[:source]].flatten.compact
       next unless inlineable?(resource, sources)
